fluidfft.bench\_analysis
========================

.. automodule:: fluidfft.bench_analysis

   
   
   .. rubric:: Functions

   .. autosummary::
   
      filter_by_shape
      load_bench
      plot_scaling
      run
   
   

   
   
   

   
   
   